|Build Status|

Packet provider
===============

The Packet resource provider for Pulumi lets you use
`Packet <https://www.packet.com/>`__ resources in your cloud programs.
To use this package, please `install the Pulumi CLI
first <https://pulumi.io/>`__.

Installing
----------

This package is available in many languages in the standard packaging
formats.

Node.js (Java/TypeScript)
~~~~~~~~~~~~~~~~~~~~~~~~~

To use from JavaScript or TypeScript in Node.js, install using either
``npm``:

::

   $ npm install @pulumi/packet

or ``yarn``:

::

   $ yarn add @pulumi/packet

Python
~~~~~~

To use from Python, install using ``pip``:

::

   $ pip install pulumi_packet

Go
~~

To use from Go, use ``go get`` to grab the latest version of the library

::

   $ go get github.com/pulumi/pulumi-packet/sdk/go/...

Reference
---------

For detailed reference documentation, please visit `the API
docs <https://pulumi.io/reference/pkg/nodejs/@pulumi/packet/index.html>`__.

.. |Build Status| image:: https://travis-ci.com/pulumi/pulumi-packet.svg?token=eHg7Zp5zdDDJfTjY8ejq&branch=master
   :target: https://travis-ci.com/pulumi/pulumi-packet
